@@ -36,7 +36,8 @@ class NodeNetwork(object):
         
         cnew = type(cnew_name, (cls,), {})
         
-        return object.__new__(cnew, *args, **kwargs)
+        #return object.__new__(cnew, *args, **kwargs)
+        return object.__new__(cnew)
 
     def __init__(self, kat):
         self.__nodes = {}
